diff pidgin-twitter.h @ 148:4e9d0fd93fb6

- in saving icon file for twitter, proper extension is used. - pointers to hash tables are organized as an array. - removed unused code. - resolved redundant code with hash table array.
author Yoshiki Yazawa <yaz@honeyplanet.jp>
date Thu, 24 Jul 2008 21:00:34 +0900
parents bef8f96ce8f2
children 588da540685a
line wrap: on
line diff
--- a/pidgin-twitter.h	Thu Jul 24 06:40:41 2008 +0900
+++ b/pidgin-twitter.h	Thu Jul 24 21:00:34 2008 +0900
@@ -39,7 +39,7 @@
 
 /* service id */
 enum {
-    unknown_service = 0,
+    unknown_service = -1,
     twitter_service,
     wassr_service,
     identica_service
@@ -47,10 +47,11 @@
 
 /* container to hold icon data */
 typedef struct _icon_data {
-    gint icon_id;        // image id
-    gboolean requested;  // TRUE if download icon has been requested
-    GList *request_list; // marker list
-    PurpleUtilFetchUrlData *fetch_data;          // icon fetch data
+    gint icon_id;           /* image id */
+    gboolean requested;     /* TRUE if download icon has been requested */
+    GList *request_list;    /* marker list */
+    PurpleUtilFetchUrlData *fetch_data; /* icon fetch data */
+    const gchar *img_type;  /* image type */
 } icon_data;
 
 /* used by got_icon_cb */
@@ -194,7 +195,7 @@
 static gboolean load_plugin(PurplePlugin *plugin);
 static gboolean unload_plugin(PurplePlugin *plugin);
 static void counter_prefs_cb(const char *name, PurplePrefType type, gconstpointer val, gpointer data);
-//static PurplePluginPrefFrame *get_plugin_pref_frame(PurplePlugin *plugin);
+
 static void init_plugin(PurplePlugin *plugin);
 static void remove_marks_func(gpointer key, gpointer value, gpointer user_data);
 static void cancel_fetch_func(gpointer key, gpointer value, gpointer user_data);
@@ -207,4 +208,9 @@
 static gboolean get_status_with_api(gpointer data);
 static void read_timestamp(const char *str, struct tm *res);
 
+static void strip_markup(gchar **str, gboolean escape);
+static gchar *strip_html_markup(const gchar *src);
+static GtkWidget *prefs_get_frame(PurplePlugin *plugin);
+
+
 #endif